@@ -15,6 +15,8 @@ class TikApi(object):
         return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
     elif resp['status'] == 5:
         return resp['result']['xss']
+    else:
+        return 'Invalid parameter has been received.'
 
   def xgorgon(self, url, cookies):
     url = self.base_url + "/xgorgon"
@@ -26,6 +28,8 @@ class TikApi(object):
         return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
     elif resp['status'] == 5:
         return resp['result']['gorgon']
+    else:
+        return 'Invalid parameter has been received.'
 
   def xkhronos(self, url, cookies):
     url = self.base_url + "/xkhronos"
@@ -36,4 +40,6 @@ class TikApi(object):
     elif resp['status'] == 1:
         return 'Missing required parameters. DM Virtuality.#6670 for proper instruction.'
     elif resp['status'] == 5:
-        return resp['result']['khronos']
\ No newline at end of file
+        return resp['result']['khronos']
+    else:
+        return 'Invalid parameter has been received.'
\ No newline at end of file
